@@ -22,9 +22,6 @@ void chum_set_pair_composition(JammoCollaborationPairComposition* pc);
 jammo_song* chum_get_current_song();
 void chum_set_current_song(jammo_song* song);
 
-int chum_get_state_of_chum();
-void chum_set_state_of_chum(int state);
-
 const char* chum_get_selected_language();
 void  chum_set_selected_language(const gchar* language);
 
