@@ -5,6 +5,7 @@
 #include "../../configure.h" //e.g. DATA_DIR
 #include "../jammo-sample-button.h"
 #include "../jammo-editing-track-view.h"
+#include "../../cem/cem.h"
 
 #include "theme.h"
 
@@ -12,8 +13,9 @@
 gboolean composition_game_file_helper_load_from_file(jammo_theme* theme, gpointer data,JammoEditingTrackView* bottom_track_view ,JammoEditingTrackView* upper_track_view) {
 
 gchar* filename = (gchar*) data;
-printf("Themeselection: Loading composition in file '%s'\n",filename);
-
+gchar* message = g_strdup_printf("Loading composition from file '%s'",filename);
+cem_add_to_log(message,J_LOG_DEBUG);
+g_free(message);
 
 JsonParser *parser;
 parser = json_parser_new ();
@@ -22,7 +24,8 @@ g_assert (JSON_IS_PARSER (parser));
 GError *error = NULL;
 if (!json_parser_load_from_file (parser, filename, &error))
 	{
-		g_print ("Error: %s\n", error->message);
+		cem_add_to_log(error->message,J_LOG_ERROR);
+		//g_print ("Error: %s\n", error->message);
 		g_error_free (error);
 		g_object_unref (parser);
 		return FALSE;
@@ -45,24 +48,26 @@ gchar* theme_name ="";
 gint variation =-1;
 
 	//string
+	/* //No need to read icon on this phase.
 	node = json_object_get_member (object, "icon");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
 		gchar* icon_name =(gchar*)  json_node_get_string (node);
-		printf("icon: '%s'\n",icon_name);
+		//printf("icon: '%s'\n",icon_name);
 	}
+	*/
 
 	//string
 	node = json_object_get_member (object, "theme");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
 		theme_name =(gchar*)  json_node_get_string (node);
-		printf("theme: '%s'\n",theme_name);
+		//printf("theme: '%s'\n",theme_name);
 	}
 
 	//int
 	node = json_object_get_member (object, "variation");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
 		variation = json_node_get_int (node);
-		printf("variation: '%d'\n",variation);
+		//printf("variation: '%d'\n",variation);
 	}
 
 	gint track_counter =1;
@@ -74,9 +79,11 @@ gint variation =-1;
 		track_array =  json_node_get_array (node);
 		length_tracks = json_array_get_length(track_array);
 	}
-	else {printf("Not any tracks\n"); }
+	else {
+		cem_add_to_log("Not any tracks for loading",J_LOG_WARN);
+	}
 
-	printf("length %d\n",length_tracks);
+	//printf("length %d\n",length_tracks);
 	int j;
 	for (j=0;j<length_tracks;j++) {
 
@@ -86,22 +93,24 @@ gint variation =-1;
 
 
 		if (track_node!=NULL && JSON_NODE_TYPE(track_node) == JSON_NODE_OBJECT){
-			printf("Found another track\n");
+			//printf("Found another track\n");
 			JammoEditingTrackView* track_view = NULL;
 			if (track_counter == 1)
 				track_view = bottom_track_view;
 			else if (track_counter == 2)
 				track_view = upper_track_view;
 			else {
-				printf("problems with loading from file\n");
+				cem_add_to_log("problems with loading from file",J_LOG_ERROR);
 			}
 			JsonObject* sub_object = json_node_get_object(track_node);
 			JsonNode *sub_node;
 			sub_node = json_object_get_member (sub_object, "track-type");
+			/* //Track-type is not used in this phase
 			if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
 				gchar* track_type =(gchar*)  json_node_get_string (sub_node);
-				printf("track-type: '%s'\n",track_type);
+				//printf("track-type: '%s'\n",track_type);
 				}
+			*/
 
 			//Array
 			sub_node = json_object_get_member (sub_object, "samples");
@@ -109,7 +118,7 @@ gint variation =-1;
 				JsonArray* sample_array =  json_node_get_array (sub_node);
 
 				guint length = json_array_get_length(sample_array);
-				printf("length %d\n",length);
+				//printf("length %d\n",length);
 				int i;
 				for (i=0;i<length;i++) {
 					JsonNode* sample_node;
@@ -123,13 +132,13 @@ gint variation =-1;
 						sub_node = json_object_get_member (sample_object, "loop_id");
 						if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
 							loop_id =  json_node_get_int (sub_node);
-							printf("loop_id: '%d'\n",loop_id);
+							//printf("loop_id: '%d'\n",loop_id);
 						}
 						//int
 						sub_node = json_object_get_member (sample_object, "slot");
 						if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
 							slot =  json_node_get_int (sub_node);
-							printf("slot: '%d'\n",slot);
+							//printf("slot: '%d'\n",slot);
 						}
 						if (track_view) {
 							ClutterActor* sample_button = theme_give_sample_button_for_this_theme_and_variation_for_this_id(theme, theme_name,variation,loop_id);
