@@ -431,30 +431,26 @@ static void remove_all_icon_animations(jammo_theme* theme) {
 /*
 Use when samplebutton is dropped to track or removed from track.
 */
-static void log_track_activity (const gchar* event, const gchar* track_name, ClutterActor* actor, TangleScrollingActor* scrolling_actor) {
-	float x = clutter_actor_get_x(actor);
-	float offset = tangle_scrolling_actor_get_scrolling_offset_x(scrolling_actor);
-
+static void log_track_activity (const gchar* event, int slot, ClutterActor* track, ClutterActor* actor) {
 	gchar* name;
 	g_object_get(actor,"sample-filename", &name,NULL); //It is sample_button
-	gchar *message = g_strdup_printf("Sample '%s' %s %s-track: slot = %d",name, event, track_name, (int)(0.5+(offset+x)/WIDTH_OF_SLOT));
+	
+	gchar* name_of_track;
+	g_object_get(track,"name", &name_of_track,NULL);
+
+	gchar *message = g_strdup_printf("Sample '%s' %s track:%s at slot = %d",name, event, name_of_track, slot);
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
 }
 
-static void on_actor_added_bottom(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
-	log_track_activity("added to", "bottom", actor,TANGLE_SCROLLING_ACTOR(user_data));
+
+static void on_actor_added(ClutterActor* track, gint slot, ClutterActor* actor, gpointer none) {
+	log_track_activity("added to", slot, track, actor);
 }
 
-static void on_actor_removed_bottom(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
-	log_track_activity("removed from", "bottom", actor,TANGLE_SCROLLING_ACTOR(user_data));
-}
-static void on_actor_added_upper(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
-	log_track_activity("added to", "upper", actor,TANGLE_SCROLLING_ACTOR(user_data));
-}
 
-static void on_actor_removed_upper(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
-	log_track_activity("removed from", "upper", actor,TANGLE_SCROLLING_ACTOR(user_data));
+static void on_actor_removed(ClutterActor* track, gint slot, ClutterActor* actor, gpointer none) {
+	log_track_activity("removed from", slot, track, actor);
 }
 
 
@@ -875,12 +871,15 @@ if (use_two_tracks) y_offset=80;
 	clutter_actor_set_size(scrolling_actor, 800.0, 120.0+y_offset);
 	clutter_container_add_actor(CLUTTER_CONTAINER(view), scrolling_actor);
 
+	//Logging activity:
+	clutter_actor_set_name(CLUTTER_ACTOR(theme->bottom_track_view),"Bottom");
+	g_signal_connect(theme->bottom_track_view, "sample-added", G_CALLBACK(on_actor_added), NULL);
+	g_signal_connect(theme->bottom_track_view, "sample-removed", G_CALLBACK(on_actor_removed), NULL);
 
-	g_signal_connect(theme->bottom_track_view, "actor-added", G_CALLBACK(on_actor_added_bottom), scrolling_actor);
-	g_signal_connect(theme->bottom_track_view, "actor-removed", G_CALLBACK(on_actor_removed_bottom), scrolling_actor);
 	if (theme->upper_track_view) {
-		g_signal_connect(theme->upper_track_view, "actor-added", G_CALLBACK(on_actor_added_upper), scrolling_actor);
-		g_signal_connect(theme->upper_track_view, "actor-removed", G_CALLBACK(on_actor_removed_upper), scrolling_actor);
+		clutter_actor_set_name(CLUTTER_ACTOR(theme->upper_track_view),"Upper");
+		g_signal_connect(theme->upper_track_view, "sample-added", G_CALLBACK(on_actor_added), NULL);
+		g_signal_connect(theme->upper_track_view, "sample-removed", G_CALLBACK(on_actor_removed), NULL);
 	}
 
 
