@@ -2,6 +2,6 @@
 
 #define JAMMERIMGPATH DATA_DIR "/jammer"
 
-#define JAMMERSOUNDPATH DATA_DIR "/jammer/jammersounds"
+#define JAMMERSOUNDPATH AUDIO_DIR "/jammersounds"
 
 void start_jammer();
