@@ -272,6 +272,10 @@ void midi_editor_start_with_miditrack_view(JammoMiditrackView* miditrack_view, J
               "highest-note", &highest_note, "lowest-note", &lowest_note,
               NULL);
 
+	//Start with zoomed IN
+	g_object_set(static_jammo_miditrack_view, "slot-width", width_of_grid_slot, "slot-height", height_of_grid_slot ,
+              NULL);
+
 	//Make editor
 	start_midi_editor();
 }
@@ -303,7 +307,8 @@ static void start_midi_editor(void) {
 	ClutterActor* actor = CLUTTER_ACTOR(static_jammo_miditrack_view); //make things easier
 	g_object_ref(actor);
 
-	clutter_container_remove_actor(CLUTTER_CONTAINER(parent), actor);
+	if (clutter_actor_get_parent(actor)) //e.g. In debug mode and some error cases
+		clutter_container_remove_actor(CLUTTER_CONTAINER(parent), actor);
 	tangle_widget_add(TANGLE_WIDGET(container_for_track),actor,NULL);  //add
 	clutter_actor_set_position(actor, 1.0, 1.0); //1.0,1.0 unless leftmost and topmost borders are not visible
 	jammo_miditrack_view_set_show_grid(static_jammo_miditrack_view,TRUE);  //show grid
