@@ -147,6 +147,40 @@ static void levelview_loaded(ClutterActor *levelview, gpointer none) {
 }
 
 
+/*
+Use when samplebutton is dropped to track or removed from track.
+*/
+static void log_track_activity (const gchar* event, int slot, ClutterActor* track, ClutterActor* actor) {
+	gchar* name;
+	g_object_get(actor,"sample-filename", &name,NULL); //It is sample_button
+
+	gchar* name_of_track;
+	g_object_get(track,"name", &name_of_track,NULL);
+
+	gchar *message = g_strdup_printf("Sample '%s' %s track:%s at slot = %d",name, event, name_of_track, slot);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
+}
+
+
+static void on_actor_added(ClutterActor* track, gint slot, ClutterActor* actor, gpointer none) {
+	log_track_activity("added to", slot, track, actor);
+}
+
+
+static void on_actor_removed(ClutterActor* track, gint slot, ClutterActor* actor, gpointer none) {
+	log_track_activity("removed from", slot, track, actor);
+}
+/*
+When editing track is registered (=loaded) add signals to it
+*/
+void fullsequencer_trackview_loaded (TangleActor* trackview, gpointer none){
+	g_signal_handlers_disconnect_by_func(trackview, fullsequencer_trackview_loaded, NULL);
+
+	g_signal_connect(trackview, "sample-added", G_CALLBACK(on_actor_added), NULL);
+	g_signal_connect(trackview, "sample-removed", G_CALLBACK(on_actor_removed), NULL);
+}
+
 
 static ClutterActor* current_levelview =NULL;
 void start_fullsequencer_gui(ClutterActor* levelview)
