@@ -3,16 +3,17 @@
 #include <glib.h>
 #include "config.h"
 
-
 FILE *ink_F;
 
-void create_ink_head()
+void
+create_ink_head()
 {
-  gchar* jammo_directory=configure_get_jammo_directory();
+  gchar* jammo_directory = configure_get_jammo_directory();
   gchar *filepath = g_build_filename(jammo_directory, "/motion_inkml.xml", NULL);
   g_free(jammo_directory);
   ink_F = fopen(filepath, "w");
-  if(ink_F ==NULL) {
+
+  if(ink_F == NULL) {
     g_print("Cannot open file INKML..\n");
     exit(EXIT_FAILURE);
   }
