@@ -1,4 +1,14 @@
-
+/*
+ * ProfileManager.cc
+ *
+ * This file is part of JamMo.
+ *
+ * (c) 2009-2011 Lappeenranta University of Technology
+ *
+ * Authors: Janne Parkkila
+ * 					Jussi Laakkonen <jussi.laakkonen@lut.fi>
+ */
+ 
 #include <iostream>
 #include <unistd.h>
 #include <sys/types.h>
@@ -6,7 +16,11 @@
 #include <sstream>
 #include <cstdlib>
 #include "ProfileManager.h"
-#include "../cem/cem.h"
+#include "gems_definitions.h"
+
+extern "C" {
+	#include "../cem/cem.h"
+}
 
 using namespace std;
 
@@ -143,9 +157,14 @@ guint32 ProfileManager::GetId()
 	return iUser;
 }
 
+StorageAgent* ProfileManager::GetStorageAgent()
+{
+	return iStorageAgent;
+}
+
 void log_wrap(char* msg, int info)
 {
-	//cem_add_to_log(msg,info);
+	cem_add_to_log(msg,info);
 	//printf("message: %s (%d)\n",msg,info);
 }
 
@@ -303,3 +322,49 @@ void profilemanager_reset_points(ProfileManager* _aManager)
 	string value = "0";
 	_aManager->EditDetails(param,value);
 }
+
+guchar* profilemanager_storage_get_password_salt(ProfileManager* _aManager)
+{
+	if(_aManager == NULL) return NULL;
+	return _aManager->GetStorageAgent()->getSalt();
+}
+
+guchar* profilemanager_storage_get_password_hash(ProfileManager* _aManager)
+{
+	if(_aManager == NULL) return NULL;
+	return _aManager->GetStorageAgent()->getPasswordHash();
+}
+
+guchar* profilemanager_storage_get_profile_hash(ProfileManager* _aManager)
+{
+	if(_aManager == NULL) return NULL;
+	return _aManager->GetStorageAgent()->getProfileHash();
+}
+
+guchar* profilemanager_storage_get_encrypted_profile(ProfileManager* _aManager)
+{
+	if(_aManager == NULL) return NULL;
+	return _aManager->GetStorageAgent()->getEncryptedProfile();
+}
+
+guint profilemanager_storage_get_encrypted_profile_size(ProfileManager* _aManager)
+{
+	if(_aManager == NULL) return NULL;
+	return _aManager->GetStorageAgent()->getEncryptedProfileSize();
+}
+
+void profilemanager_storage_set_password_salt(ProfileManager* _aManager, guchar* _salt)
+{
+	_aManager->GetStorageAgent()->setSalt(_salt);
+}
+
+void profilemanager_storage_set_password_hash(ProfileManager* _aManager, guchar* _hash)
+{
+	_aManager->GetStorageAgent()->setPasswordHash(_hash);
+}
+
+void profilemanager_storage_set_encrypted_profile(ProfileManager* _aManager, guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size)
+{
+	_aManager->GetStorageAgent()->setEncryptedProfile(_profile_hash, _encrypted_profile, _e_profile_size);
+}
+
