@@ -1,3 +1,14 @@
+/*
+ * ProfileManager.h
+ *
+ * This file is part of JamMo.
+ *
+ * (c) 2009-2011 Lappeenranta University of Technology
+ *
+ * Authors: Janne Parkkila
+ * 					Jussi Laakkonen <jussi.laakkonen@lut.fi>
+ */
+ 
 #ifndef __GEMS_PROFILEMANAGER_H_
 #define __GEMS_PROFILEMANAGER_H_
 
@@ -33,6 +44,8 @@ public:
 	gboolean ForceUser(guint32 userID);
 	// Get id
 	guint32 GetId();
+	
+	StorageAgent* GetStorageAgent();
 
 private:
 	
@@ -177,6 +190,17 @@ gboolean profilemanager_remove_points(ProfileManager* _aManager, guint32 _value)
 /* Reset points (set to zero) */
 void profilemanager_reset_points(ProfileManager* _aManager);
 
+/* For encrypted profile data */
+
+guchar* profilemanager_storage_get_password_salt(ProfileManager* _aManager);
+guchar* profilemanager_storage_get_password_hash(ProfileManager* _aManager);
+guchar* profilemanager_storage_get_profile_hash(ProfileManager* _aManager);
+guchar* profilemanager_storage_get_encrypted_profile(ProfileManager* _aManager);
+guint profilemanager_storage_get_encrypted_profile_size(ProfileManager* _aManager);
+void profilemanager_storage_set_password_salt(ProfileManager* _aManager, guchar* _salt);
+void profilemanager_storage_set_password_hash(ProfileManager* _aManager, guchar* _hash);
+void profilemanager_storage_set_encrypted_profile(ProfileManager* _aManager, guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size);
+
 #ifdef __cplusplus
 }
 #endif
