@@ -43,6 +43,7 @@ gems_components* gems_get_data()
 		gems_data->ph = NULL;
 		gems_data->ph_cb = NULL;
 		gems_data->communication = NULL;
+		gems_data->security_context = NULL;
 		gems_data->service_jammo = NULL;
 		gems_data->service_profile = NULL;
 		gems_data->service_group = NULL;
@@ -80,6 +81,11 @@ gems_communication_data* gems_get_communication()
 	return gems_get_data()->communication;
 }
 
+gems_security_context* gems_get_security_contexts()
+{
+	return gems_data->security_context;
+}
+
 gems_service_jammo* gems_get_service_jammo()
 {
 	return gems_get_data()->service_jammo;
