@@ -17,6 +17,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <netinet/in.h>
+#include <openssl/evp.h>
 #include "gems_definitions.h"
 #include "ProfileManager.h"
 
@@ -147,7 +148,20 @@ typedef struct {
 	GList* rejected; // contains gems_connection, rejected/version mismatch
 } gems_communication_data;
 
+typedef struct{
+//	gems_service_songbank* mySBobj;	
+	MPeerHood* peerHood;	
+	unsigned short sbPort; //songbank service port on this device
+	GList* connections;    // connections to SongBankComm
+//	MAbstractConnection *connection;
+//	pthread_t connThread;
+//	int threadId;
+}SongBankComm;
 
+typedef struct{
+	char* baseDirectory;
+	SongBankComm* sbComm;
+}gems_service_songbank;
 
 /* Connection error items, every errorous connection to a device
    increases the errorcount, more errors -> increase connection interval
@@ -161,6 +175,13 @@ typedef struct {
 	GTimer* connection_timer;
 } gems_connection_error;
 
+
+typedef struct {
+	EVP_CIPHER_CTX* encryption;
+	EVP_CIPHER_CTX* decryption;
+	EVP_MD_CTX* digest;
+} gems_security_context;
+
 // High level struct for GEMS
 typedef struct {
 	// Profile Manager
@@ -176,6 +197,8 @@ typedef struct {
 	/* Communication */
 	gems_communication_data* communication;
 	
+	gems_security_context* security_context;
+	
 	/* Services*/
 	gems_service_jammo* service_jammo;
 	//gems_service_aa* service_aa;
@@ -191,6 +214,8 @@ typedef struct {
 
 	gems_teacher_connection* teacher_connection;
 	// Set values to .jammo-profiles/<id>.csv
+
+	gems_service_songbank* service_songbank;
 	
 } gems_components;
 
