@@ -556,19 +556,19 @@ static gboolean gst_jammo_looper_setcaps (GstBaseSrc * basesrc, GstCaps * caps)
   /* allocate a new buffer suitable for this pad */
   switch (src->format) {
     case GST_JAMMO_LOOPER_FORMAT_S16:
-      printf("format is now gint16\n");
+      //printf("format is now gint16\n");
       src->sample_size = sizeof (gint16);
       break;
     case GST_JAMMO_LOOPER_FORMAT_S32:
-      printf("format is now gint32\n");
+      //printf("format is now gint32\n");
       src->sample_size = sizeof (gint32);
       break;
     case GST_JAMMO_LOOPER_FORMAT_F32:
-      printf("format is now gfloat32\n");
+      //printf("format is now gfloat32\n");
       src->sample_size = sizeof (gfloat);
       break;
     case GST_JAMMO_LOOPER_FORMAT_F64:
-      printf("format is now gfloat32\n");
+      //printf("format is now gfloat32\n");
       src->sample_size = sizeof (gdouble);
       break;
     default:
@@ -931,7 +931,7 @@ static void gst_jammo_looper_set_property (GObject * object, guint prop_id,
 					loop->start *= (gdouble)src->tempo / (gdouble)tempo;
 				}
       	src->tempo = tempo;
-      	printf("tempo changed to %u\n", src->tempo);
+      	//printf("tempo changed to %u\n", src->tempo);
 			}
       break;
     case PROP_PITCH: {
@@ -942,7 +942,7 @@ static void gst_jammo_looper_set_property (GObject * object, guint prop_id,
 		  		src->pitch=NULL;
 		  	}
 		    src->pitch = g_strdup_printf("%s",g_value_get_string(value));
-		    printf("pitch changed to %s\n", src->pitch);
+		    //printf("pitch changed to %s\n", src->pitch);
 				for (i=0;i<g_list_length(src->loops);i++) {
 					loop = g_list_nth_data(src->loops, i);
 					sf_close(loop->sndfileptr);
