@@ -269,8 +269,8 @@ SF_INFO sfinfo;
 sfinfo.format = 0;
 SNDFILE * sndfileptr = sf_open(filename, SFM_READ, &sfinfo);
 if (sndfileptr==NULL) {
-	printf("error opening file %s\n", filename);
-	exit(1);
+	printf("\nFATAL-ERROR: gstjammosampler can't open file '%s'. Better to quit (...but keep running)\n", filename);
+	//exit(1);
 }
 
 /*	Same samples are not read to memory multiple times
@@ -315,12 +315,17 @@ if (src->wav_based_instrument[index]->sampletable ==NULL) {
 		src->wav_based_instrument[index]->filename =realloc(src->wav_based_instrument[index]->filename, (strlen(filename)+1)*sizeof(gchar) );
 	strcpy(src->wav_based_instrument[index]->filename, filename);
 	/* read audio data to sample table */
-	if (sf_read_short(sndfileptr, src->wav_based_instrument[index]->sampletable, file_size)!=file_size){
-		printf("error reading sample file\n");
+	if (sndfileptr){
+		if (sf_read_short(sndfileptr, src->wav_based_instrument[index]->sampletable, file_size)!=file_size){
+			printf("error reading sample file\n");
+			}
 		}
+	//TODO: load something silence to sampletable
+	//else{ }
 }
 
-sf_close(sndfileptr);
+if (sndfileptr)
+	sf_close(sndfileptr);
 }
 
 
